/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
#+
#+     Internet Radio Automation & Encoding Toolkit
#+
#+     Copyright (C) 2018, 2019, 2020, 2021 by Kevin C. O'Kane
#+
#+     Kevin C. O'Kane
#+     kc.okane@gmail.com
#+     https://www.cs.uni.edu/~okane
#+     https://threadsafebooks.com/
#+
#+ This program is free software; you can redistribute it and/or modify
#+ it under the terms of the GNU General Public License as published by
#+ the Free Software Foundation; either version 2 of the License, or
#+ (at your option) any later version.
#+
#+ This program is distributed in the hope that it will be useful,
#+ but WITHOUT ANY WARRANTY; without even the implied warranty of
#+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#+ GNU General Public License for more details.
#+
#+ You should have received a copy of the GNU General Public License
#+ along with this program; if not, write to the Free Software
#+ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#+
#++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/

//	Sept 22, 2022

#include "includes.h"
#include "common-externs.h"

#define SLASH '/'

void	on_tooltips_toggled(GtkWidget *b) { // turn on/off tooltips
	static int on = 1;
	if (! gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(b))) {
		on = 0;
		gtk_widget_set_has_tooltip (GTK_WIDGET(bandwidth), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(ray_rotate), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(bandstart), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(save3), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(radial_start), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(sprinkleDamp), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(agc_gain), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(TimeToHour), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(show_video), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(antenna), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(sprinkle_count), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(no_graphs), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(radial_decay), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(recenter1), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(noMove1), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(albumScroll), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(albumForward), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(albumBack), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(showCovers), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(mediaGain), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(micThreshold1), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(finish_pgm), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(micMute), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(about), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(above_bars), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(addEntry1), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(agc), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(agcMod), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(alt_search1), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(audioCalibrate), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(barWidth), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(bullseye), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(button10), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(button11), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(button12), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(button13), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(button14), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(button15), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(button1), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(button2), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(button3), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(button5), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(button6), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(button8), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(button9), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(check10), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(check11), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(check12), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(check1), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(check2), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(check3), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(check4), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(check5), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(check6), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(check7), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(check8), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(check9), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(choose1), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(circular), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(clipThreshold), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(clrPgm), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(clrPgm1), FALSE);

		gtk_widget_set_has_tooltip (GTK_WIDGET(connectGraph), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(currentFile), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(decorations), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(del10), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(del11), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(del12), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(del13), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(del14), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(del15), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(del2), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(del3), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(del4), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(del7), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(del8), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(del9), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(displayBars), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(draw1), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(draw2), FALSE);

		gtk_widget_set_has_tooltip (GTK_WIDGET(entry10), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(entry11), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(entry12), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(entry13), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(entry14), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(entry15), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(entry1), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(entry2), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(entry3), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(entry4), FALSE);

		gtk_widget_set_has_tooltip (GTK_WIDGET(entry7), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(entry8), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(entry9), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(eqReset), FALSE);

		gtk_widget_set_has_tooltip (GTK_WIDGET(haltProgram), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(masterVolume), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(maxGain), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(meters), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(nextPlay), FALSE);

		gtk_widget_set_has_tooltip (GTK_WIDGET(p10), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p11), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p12), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p13), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p14), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p15), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p16), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p17), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p18), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p19), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p1), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p20), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p21), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p22), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p23), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p24), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p25), FALSE);

		gtk_widget_set_has_tooltip (GTK_WIDGET(p2), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p3), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p4), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p5), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p6), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p7), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p8), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p9), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(pauseAtEnd), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(pauseVideo), FALSE);

		gtk_widget_set_has_tooltip (GTK_WIDGET(Playerx), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(Playerx1), FALSE);

		gtk_widget_set_has_tooltip (GTK_WIDGET(PlayPgm), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(PlayPgm1), FALSE);

		gtk_widget_set_has_tooltip (GTK_WIDGET(rampDown), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(rampUp), FALSE);

		gtk_widget_set_has_tooltip (GTK_WIDGET(randomize), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(randomize1), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(rayCount), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(recenter), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(save1), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(save2), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(scan_times), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(scroll2), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(scroll), FALSE);

		gtk_widget_set_has_tooltip (GTK_WIDGET(search_again1), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(search_again), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(search_scroll), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(sgrStudio), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(shadow_offset), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(showCurrent), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(showCurrent1), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(skipNext), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(skipThis), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(slideTime), FALSE);

		gtk_widget_set_has_tooltip (GTK_WIDGET(sort), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(sort1), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(spec12), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(spec20), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(spec7), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(spikes1), FALSE);

		gtk_widget_set_has_tooltip (GTK_WIDGET(tower), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(tower_rays), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(tower_circles), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(spikes), FALSE);

		gtk_widget_set_has_tooltip (GTK_WIDGET(timeNext), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(timer), FALSE);

		gtk_widget_set_has_tooltip (GTK_WIDGET(tooltips), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(traces), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(noBackPic), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(up10), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(up11), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(up12), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(up1), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(up2), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(up3), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(up4), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(up5), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(up6), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(up7), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(up8), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(up9), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(vlcPosition), FALSE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(vlcSpinRate), FALSE);
		}

	else {
		on = 1;

		gtk_widget_set_has_tooltip (GTK_WIDGET(ray_rotate), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(bandstart), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(bandwidth), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(radial_decay), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(radial_start), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(noBackPic), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(sprinkleDamp), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(save3), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(agc_gain), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(TimeToHour), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(antenna), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(show_video), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(tower_rays), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(sprinkle_count), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(no_graphs), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(ray_rotate), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(recenter1), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(noMove1), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(albumScroll), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(albumForward), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(albumBack), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(showCovers), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(mediaGain), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(micThreshold1), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(finish_pgm), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(finish_pgm1), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(micMute), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(about), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(above_bars), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(addEntry1), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(agc), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(agcMod), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(alt_search1), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(audioCalibrate), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(barWidth), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(bullseye), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(button10), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(button11), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(button12), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(button13), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(button14), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(button15), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(button1), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(button2), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(button3), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(button5), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(button6), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(button8), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(button9), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(check10), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(check11), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(check12), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(check1), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(check2), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(check3), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(check4), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(check5), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(check6), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(check7), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(check8), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(check9), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(choose1), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(circular), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(clipThreshold), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(clrPgm), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(clrPgm1), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(connectGraph), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(currentFile), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(decorations), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(del10), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(del11), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(del12), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(del13), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(del14), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(del15), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(del2), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(del3), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(del4), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(del7), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(del8), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(del9), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(displayBars), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(draw1), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(draw2), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(entry10), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(entry11), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(entry12), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(entry13), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(entry14), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(entry15), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(entry1), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(entry2), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(entry3), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(entry4), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(entry7), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(entry8), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(entry9), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(eqReset), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(haltProgram), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(masterVolume), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(maxGain), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(meters), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(nextPlay), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p10), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p11), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p12), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p13), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p14), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p15), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p16), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p17), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p18), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p19), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p1), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p20), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p21), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p22), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p23), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p24), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p25), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p2), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p3), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p4), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p5), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p6), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p7), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p8), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(p9), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(pauseAtEnd), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(pauseVideo), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(Playerx), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(Playerx1), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(PlayPgm), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(PlayPgm1), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(rampDown), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(rampUp), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(randColors), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(randomize), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(randomize1), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(rayCount), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(recenter), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(save1), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(save2), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(scan_times), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(scroll2), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(scroll), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(search_again1), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(search_again), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(search_scroll), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(sgrStudio), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(shadow_offset), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(showCurrent), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(showCurrent1), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(skipNext), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(skipThis), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(slideTime), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(sort), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(sort1), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(spec12), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(spec20), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(spec7), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(tower), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(tower_circles), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(spikes1), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(spikes), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(sw1), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(timeNext), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(timer), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(tooltips), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(traces), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(up10), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(up11), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(up12), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(up1), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(up2), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(up3), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(up4), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(up5), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(up6), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(up7), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(up8), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(up9), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(vlcPosition), TRUE);
		gtk_widget_set_has_tooltip (GTK_WIDGET(vlcSpinRate), TRUE);

		}
	}
