/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
#+
#+     Internet Radio Automation & Encoding Toolkit
#+
#+     Copyright (C) 2018, 2019, 2020, 2021 by Kevin C. O'Kane
#+
#+     Kevin C. O'Kane
#+     kc.okane@gmail.com
#+     https://www.cs.uni.edu/~okane
#+     https://threadsafebooks.com/
#+
#+ This program is free software; you can redistribute it and/or modify
#+ it under the terms of the GNU General Public License as published by
#+ the Free Software Foundation; either version 2 of the License, or
#+ (at your option) any later version.
#+
#+ This program is distributed in the hope that it will be useful,
#+ but WITHOUT ANY WARRANTY; without even the implied warranty of
#+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#+ GNU General Public License for more details.
#+
#+ You should have received a copy of the GNU General Public License
#+ along with this program; if not, write to the Free Software
#+ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#+
#++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/

//	Nov 4, 2022

#include "includes.h"
#include "common-externs.h"

#define SLASH '/'

void    sprinkles(cairo_t *cr, double z, double len, int i, double hor, double ver) {

	if(lastR1[i]>len) {
		spots(cr, hor, ver, lastR1[i], z);
		}

	if (sprinkleCount == 1) return;

	if(lastR2[i]>len) {
		spots(cr, hor, ver, lastR2[i], z);
		}

	if (sprinkleCount == 2) return;

	if(lastR3[i]>len) {
		spots(cr, hor, ver, lastR3[i], z);
		}

	if (sprinkleCount == 3) return;

	if(lastR4[i]>len) {
		spots(cr, hor, ver, lastR4[i], z);
		}

	if (sprinkleCount == 4) return;

	if(lastR5[i]>len) {
		spots(cr, hor, ver, lastR5[i], z);
		}

	if (sprinkleCount == 5) return;

	if(lastR6[i]>len) {
		spots(cr, hor, ver, lastR6[i], z);
		}

	if (sprinkleCount == 6) return;

	if(lastR7[i]>len) {
		spots(cr, hor, ver, lastR7[i], z);
		}

	if (sprinkleCount == 7) return;

	if(lastR8[i]>len) {
		spots(cr, hor, ver, lastR8[i], z);
		}

	if (sprinkleCount == 8) return;

	if(lastR9[i]>len) {
		spots(cr, hor, ver, lastR9[i], z);
		}

	if (sprinkleCount == 9) return;

	if(lastRA[i]>len) {
		spots(cr, hor, ver, lastRA[i], z);
		}

	}

