/*+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
#+
#+     Glade / Gtk Programming
#+
#+     Copyright (C) 2020, 2021 by Kevin C. O'Kane
#+
#+     Kevin C. O'Kane
#+     kc.okane@gmail.com
#+     https://www.cs.uni.edu/~okane
#+     http://threadsafebooks.com/
#+
#+ This program is free software; you can redistribute it and/or modify
#+ it under the terms of the GNU General Public License as published by
#+ the Free Software Foundation; either version 2 of the License, or
#+ (at your option) any later version.
#+
#+ This program is distributed in the hope that it will be useful,
#+ but WITHOUT ANY WARRANTY; without even the implied warranty of
#+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#+ GNU General Public License for more details.
#+
#+ You should have received a copy of the GNU General Public License
#+ along with this program; if not, write to the Free Software
#+ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#+
#++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/

//	Oct 28, 2022

#ifndef COMMON_WIDGETS_H
#define COMMON_WIDGETS_H

GtkWidget *current_stack = NULL;

GtkWidget        *TopBG;
GtkWidget        *au_fixed;
GtkWidget        *pg8_fixed;
GtkWidget        *ct_fixed;
GtkWidget        *pg_fixed;
GtkWidget        *ed_fixed;
GtkWidget        *pg_edit;
GtkWidget        *mini_mode;
GtkWidget        *video_bg;
GtkWidget        *video_bg1;
GtkEntry        *alt_search;
GtkEntry        *alt_search1;
GtkWidget       *search_scroll = NULL;
GtkWidget       *art_metadata;
GtkWidget       *search_again;
GtkWidget       *solid_digital_arcs;
GtkWidget       *search_again1;
GtkWidget       *sprinkleDamp;
GtkWidget       *no_graphs;
GtkWidget       *d1mask;
GtkWidget       *noBackPic;
GtkWidget       *web2_clear;
GtkWidget       *search_again1;
GtkWidget       *ray_rotate;
GtkWidget       *agc_gain;
GtkWidget       *time_of_day;
GtkWidget       *camdraw;
GtkWidget	*webkit;
GtkWidget	*zoom_level;
GtkWidget	*video_panel;
GtkWidget	*radio_bars, *radio_vu, *radio_digital, *radio_fans;
WebKitSettings	*web_settings;
GtkWidget	*web_playlist;
GtkWidget	*web_entry;
GtkWidget	*web_button;
GtkWidget	*web_panel;
GtkWidget	*vlcX;
GtkWidget	*mpv_player;

// GtkWidget	*large462;
GtkWidget	*switcher1;
GtkWidget	*pg;
GtkWidget	*bandwidth;
GtkWidget	*bandstart;
GtkWidget	*show_video;
GtkWidget	*sprinkle_count;
GtkWidget	*Cam0;
GtkWidget	*cam0_image = NULL;

GdkColor        color;
GdkPixbuf       *pixbuf;
GdkPixbuf       *cambuf;
GdkWindow	*gdk_window;
GError          *err;

GtkAdjustment   *adjustment10; // preAmp position
GtkAdjustment   *adjustment11; // h60 position - 60Hz
GtkAdjustment   *adjustment12; // h170 position
GtkAdjustment   *adjustment13; // h310 position
GtkAdjustment   *adjustment14; // h600 position
GtkAdjustment   *adjustment15; // h1000 position
GtkAdjustment   *adjustment16; // h3000 position
GtkAdjustment   *adjustment17; // h6000 position
GtkAdjustment   *adjustment18; // h12000 position
GtkAdjustment   *adjustment19; // h14000 position
GtkAdjustment   *adjustment20; // h16000 position 26000Hz
GtkAdjustment   *adjustment45; // bar density
GtkAdjustment   *adjustment49; // ray rotate position

GtkBuilder      *builder;

GtkEntry        *entry1;
GtkEntry        *entry10;
GtkEntry        *entry11;
GtkEntry        *entry12;
GtkEntry        *entry13;
GtkEntry        *entry14;
GtkEntry        *entry15;
GtkEntry        *entry2;
GtkEntry        *entry3;
GtkEntry        *entry4;
GtkEntry        *entry7;
GtkEntry        *entry8;
GtkEntry        *entry9;
GtkEntry        *g_dbox1Entry;
GtkWidget       *stack1;
GtkWidget       *about;
GtkWidget       *antenna;
GtkWidget       *addEntry1;
GtkWidget       *agc;
GtkWidget       *agcLbl1;
GtkWidget       *agcLbl2;
GtkWidget       *agcMod;
GtkWidget       *albumBack;
GtkWidget       *albumForward;
GtkWidget       *albumScroll;
GtkWidget       *audioCalibrate;
GtkWidget       *audio;
GtkWidget       *background;
GtkWidget       *barWidth;
GtkWidget       *bullseye;
GtkWidget       *button1;
GtkWidget       *button10;
GtkWidget       *button11;
GtkWidget       *button12;
GtkWidget       *button13;
GtkWidget       *button14;
GtkWidget       *button15;
GtkWidget       *button2;
GtkWidget       *button3;
GtkWidget       *button5;
GtkWidget       *button6;
GtkWidget       *button[8];
GtkWidget       *button8;
GtkWidget       *button9;
GtkWidget       *calibrateLbl;
GtkWidget       *cbox1;
GtkWidget       *check1;
GtkWidget       *check10;
GtkWidget       *check11;
GtkWidget       *check12;
GtkWidget       *check2;
GtkWidget       *check3;
GtkWidget       *check4;
GtkWidget       *check5;
GtkWidget       *check6;
GtkWidget       *check7;
GtkWidget       *check8;
GtkWidget       *check9;
GtkWidget       *choose1;
GtkWidget       *circular;
GtkWidget       *classical;
GtkWidget       *clevel;
GtkWidget       *clipThreshold;
GtkWidget       *clrPgm;
GtkWidget       *clrPgm1;
GtkWidget       *club;
GtkWidget       *connectGraph;
GtkWidget       *controls;
GtkWidget       *movie;
GtkWidget       *covers;
GtkWidget       *currentFile;
GtkWidget       *dance;
GtkWidget       *decorations;
GtkWidget       *del10;
GtkWidget       *del11;
GtkWidget       *del12;
GtkWidget       *del13;
GtkWidget       *del14;
GtkWidget       *del15;
GtkWidget       *del2;
GtkWidget       *del3;
GtkWidget       *del4;
GtkWidget       *del7;
GtkWidget       *del8;
GtkWidget       *del9;
GtkWidget       *displayBars;
GtkWidget       *draw3;
GtkWidget       *video_draw;
GtkWidget       *dxb1;
GtkWidget       *dxb2;
GtkWidget       *egg_image;
GtkWidget       *empty;
GtkWidget       *eqReset;
GtkWidget       *finish_pgm;
GtkWidget       *finish_pgm1;
GtkWidget       *first;
GtkWidget       *fixed1;
GtkWidget       *fixed2;
GtkWidget       *fixed_slides;
GtkWidget       *flat;
GtkWidget       *fullBass;
GtkWidget       *fullBassTreble;
GtkWidget       *fullTreble;
GtkWidget       *g_btn_play;
GtkWidget       *g_btn_play2;
GtkWidget       *g_dbox1;
GtkWidget       *g_image1;
GtkWidget       *g_scale1;
GtkWidget       *h1000;
GtkWidget       *h12000;
GtkWidget       *h14000;
GtkWidget       *h16000;
GtkWidget       *h170;
GtkWidget       *h3000;
GtkWidget       *h310;
GtkWidget       *h60;
GtkWidget       *h600;
GtkWidget       *h6000;
GtkWidget       *haltProgram;
//GtkWidget       *haltProgram1;
GtkWidget       *headphones;
GtkWidget       *highLabel;
GtkWidget       *horLabel;
GtkWidget       *image13;
GtkWidget       *image14;
GtkWidget       *image15;
GtkWidget       *image16;
GtkWidget       *image17;
GtkWidget       *image18;
GtkWidget       *image19;
GtkWidget       *image20;
GtkWidget       *image21;
GtkWidget       *L1;
GtkWidget       *L10;
GtkWidget       *L1000;
GtkWidget       *L12000;
GtkWidget       *L14000;
GtkWidget       *L16000;
GtkWidget       *L170;

GtkWidget       *L2;
GtkWidget       *L3;
GtkWidget       *L3000;
GtkWidget       *L310;
GtkWidget       *L4;
GtkWidget       *L5;
GtkWidget       *L6;
GtkWidget       *L60;
GtkWidget       *L600;
GtkWidget       *L6000;
GtkWidget       *L7;
GtkWidget       *L8;
GtkWidget       *L9;
GtkWidget       *largeHall;
GtkWidget       *Lattack;
GtkWidget       *lbl1;
GtkWidget       *lbl10;
GtkWidget       *lbl11;
GtkWidget       *lbl12;
GtkWidget       *lbl13;
GtkWidget       *lbl14;
GtkWidget       *lbl15;
GtkWidget       *lbl16;
GtkWidget       *lbl17;
GtkWidget       *lbl18;
GtkWidget       *lbl19;
GtkWidget       *lbl2;
GtkWidget       *lbl20;
GtkWidget       *lbl21;
GtkWidget       *lbl22;
GtkWidget       *lbl23;

GtkWidget       *lbl24;
GtkWidget       *lbl25;
GtkWidget       *lbl3;
GtkWidget       *lbl4;
GtkWidget       *lbl5;
GtkWidget       *lbl6;
GtkWidget       *lbl7;
GtkWidget       *lbl8;
GtkWidget       *lbl9;
GtkWidget       *live;
GtkWidget       *Lknee;
GtkWidget       *Lmakeup;
GtkWidget       *Lratio;
GtkWidget       *Lrelease;
GtkWidget       *Lrmspeak;
GtkWidget       *Lthreshold;
GtkWidget       *masterVolLevel;        // label
GtkWidget       *masterVolume;          // slider
GtkWidget       *maxGain;
GtkWidget       *mediaGain;
GtkWidget       *micMute;
GtkWidget       *micThreshold1;
GtkWidget       *more;
GtkWidget       *narrow;
GtkWidget       *nextPlay;
GtkWidget       *noMove1;
GtkWidget       *openMedia;

GtkWidget       *p1;
GtkWidget       *p10;
GtkWidget       *p10Time;
GtkWidget       *p10TimeEnd;
GtkWidget       *p10TimeLength;
GtkWidget       *p11;
GtkWidget       *p11Time;
GtkWidget       *p11TimeEnd;
GtkWidget       *p11TimeLength;
GtkWidget       *p12;
GtkWidget       *p12Time;
GtkWidget       *p12TimeEnd;
GtkWidget       *p12TimeLength;
GtkWidget       *p13;
GtkWidget       *p14;
GtkWidget       *p15;
GtkWidget       *p16;
GtkWidget       *p17;
GtkWidget       *p18;
GtkWidget       *p19;
GtkWidget       *p1Time;
GtkWidget       *p1TimeEnd;
GtkWidget       *p1TimeLength;
GtkWidget       *p2;
GtkWidget       *p20;
GtkWidget       *p21;
GtkWidget       *p22, *p23, *p24, *p25;
GtkWidget       *p2Time;
GtkWidget       *p2TimeEnd;
GtkWidget       *p2TimeLength;

GtkWidget       *p3;
GtkWidget       *p3Time;
GtkWidget       *p3TimeEnd;
GtkWidget       *p3TimeLength;
GtkWidget       *p4;
GtkWidget       *p4Time;
GtkWidget       *p4TimeEnd;
GtkWidget       *p4TimeLength;
GtkWidget       *p5;
GtkWidget       *p5Time;
GtkWidget       *p5TimeEnd;
GtkWidget       *p5TimeLength;
GtkWidget       *p6;
GtkWidget       *p6Time;
GtkWidget       *p6TimeEnd;
GtkWidget       *p6TimeLength;
GtkWidget       *p7;
GtkWidget       *p7Time;
GtkWidget       *p7TimeEnd;
GtkWidget       *p7TimeLength;
GtkWidget       *p8;
GtkWidget       *p8Time;
GtkWidget       *p8TimeEnd;
GtkWidget       *p8TimeLength;
GtkWidget       *p9;
GtkWidget       *p9Time;
GtkWidget       *p9TimeEnd;
GtkWidget       *p9TimeLength;
GtkWidget       *party;
GtkWidget       *pauseAtEnd;
GtkWidget       *pauseVideo;

GtkWidget       *up1;
GtkWidget       *up10;
GtkWidget       *up11;
GtkWidget       *up12;
GtkWidget       *up2;
GtkWidget       *up3;
GtkWidget       *up4;
GtkWidget       *up5;
GtkWidget       *up6;
GtkWidget       *up7;
GtkWidget       *up8;
GtkWidget       *up9;

GtkWidget       *pg0;
GtkWidget       *pg1;
GtkWidget       *pg2;
GtkWidget       *pg8;
GtkWidget       *Playerx;
GtkWidget       *Playerx1;
GtkWidget       *PlayPgm;
GtkWidget       *PlayPgm1;
GtkWidget       *pop;
GtkWidget       *posLbl;
GtkWidget       *preAmp;
GtkWidget       *preAmp1Label;
GtkWidget       *preampLbl;
GtkWidget       *preAmpLbl1;
GtkWidget       *presetBack;
GtkWidget       *programMode;
GtkWidget       *programMode1;
GtkWidget       *radial_decay;
GtkWidget       *radial_start;
GtkWidget       *rampDown;
GtkWidget       *rampSpeedDown;
GtkWidget       *rampSpeedUp;
GtkWidget       *rampUp;
GtkWidget       *randomize;
GtkWidget       *randomize1;
GtkWidget       *rayCount;

GtkWidget       *sgrStudio;
GtkWidget       *shadowWidthLbl;
GtkWidget       *showCovers;
GtkWidget       *showCurrent;
GtkWidget       *showCurrent1;
GtkWidget       *SideSlidePanel;
GtkWidget       *sink;
GtkWidget       *ska;
GtkWidget       *skipNext;
GtkWidget       *skipThis;
GtkWidget       *SlidesImage;
GtkWidget       *slideTime;
GtkWidget       *sock1;
GtkWidget       *soft;
GtkWidget       *softRock;

GtkAdjustment   *adjustment32; // albums
GtkAdjustment   *adjustment33; // slides
GtkAdjustment   *adjustment35; // master volume

GtkWidget       *sort;  // alpha sort
GtkWidget       *sort1;  // alpha sort
GtkWidget       *source;
GtkWidget       *spec12;
GtkWidget       *spec20;
GtkWidget       *spec7;
GtkWidget       *spikes;
GtkWidget       *spikes1;

GtkWidget       *sprinkle_acc;
GtkWidget       *sprinkle_gravity;
GtkWidget       *stk1;
GtkWidget       *sw1;
GtkWidget       *techno;
GtkWidget       *timeNext;
GtkWidget       *timer;
GtkWidget       *TimeToHour;
GtkWidget       *tooltips;
GtkWidget       *Top1;
GtkWidget       *TopTop;
GtkWidget       *tower;
GtkWidget       *tower_circles;
GtkWidget       *tower_rays;
GtkWidget       *traces;
GtkWidget       *verLabel;
GtkWidget       *visual = NULL;

GtkWidget       *vlcPosition;
GtkWidget       *vlcSpinRate;
GtkWidget       *vumeter;
GtkWidget       *vumeter1;
GtkWidget       *wideLabel;
GtkWidget       *window;

//	program and edit panel scroll bars

GtkWidget       *scroll2 = NULL;
GtkWidget       *scroll = NULL;

GtkWidget        *shadow_offset;

GtkWidget       *randColors;
GtkWidget       *rayLbl;
GtkWidget       *recenter;
GtkWidget       *recenter1;
GtkWidget       *reggae;
GtkWidget       *rock;
GtkWidget       *save1;
GtkWidget       *save2;
GtkWidget       *save3;
GtkWidget       *save4;
GtkWidget       *scan_times;
GtkWidget       *scan_times1;

GtkCssProvider  *cssProviderUP;
GtkCssProvider  *cssProviderProg;
GtkCssProvider  *cssProviderDOWN;
GtkCssProvider  *cssProviderpauseVideo;
GtkCssProvider  *cssProviderpauseAtEnd;
GtkCssProvider  *cssProvidertooltips;
GtkCssProvider  *cssProvider_top;
GtkCssProvider  *cssProvider_entry1;
GtkCssProvider  *cssProvider_entry2;
GtkCssProvider  *cssProvider_entry3;
GtkCssProvider  *cssProvider_entry4;

libvlc_instance_t	*inst = NULL;
libvlc_media_player_t	*mediaPlayer = NULL;
libvlc_media_t		*media = NULL;
libvlc_equalizer_t	*equalizer = NULL;
// static libvlc_compressor_t	*compressor = NULL; // not yet active

GtkWidget	*frame1;

GtkAdjustment   *adjustment8; // vlcPosition


GtkAdjustment	*adjustment31; // mic volume
GtkAdjustment	*adjustment34; // weather
GtkAdjustment	*adjustment9; // vlcSpinRate
GtkWidget       *above_bars;
GtkWidget       *above_bars1;
GtkWidget       *draw1;
GtkWidget       *drawV;
GtkWidget       *cam0_active;
GtkWidget       *draw2;
GtkWidget       *draw4;
GtkWidget       *meters;
GtkWidget       *micGain;
GtkWidget	*showCurrent2;
GtkWidget	*xbox2;

#endif
