* {
  min-height: 2px;
  min-width: 1px;
  padding-left: 0px;
  padding-right: 0px; 
  transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); 
  border: 0px solid;
  border-radius: 0px;
  margin: 0px;
  padding: 0px 0px;
  border-color: #FFBDBD;
  background-color: blue; }
button.text-button {
  padding-left: 0px;
  padding-right: 0px; 
  background-color: blue;
  color: blue;
  }
