/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
#+
#+     Internet Radio Automation & Encoding Toolkit
#+
#+     Copyright (C) 2018, 2019, 2020, 2021 by Kevin C. O'Kane
#+
#+     Kevin C. O'Kane
#+     kc.okane@gmail.com
#+     https://www.cs.uni.edu/~okane
#+     https://threadsafebooks.com/
#+
#+ This program is free software; you can redistribute it and/or modify
#+ it under the terms of the GNU General Public License as published by
#+ the Free Software Foundation; either version 2 of the License, or
#+ (at your option) any later version.
#+
#+ This program is distributed in the hope that it will be useful,
#+ but WITHOUT ANY WARRANTY; without even the implied warranty of
#+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#+ GNU General Public License for more details.
#+
#+ You should have received a copy of the GNU General Public License
#+ along with this program; if not, write to the Free Software
#+ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#+
#++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/

//	Nov 4, 2022

#include "includes.h"
#include "common-externs.h"

#define SLASH '/'

//----------------------------------------------------
//
// draw frequency spectrum or volume level graphs
//
//----------------------------------------------------

gboolean on_draw1_draw (GtkDrawingArea *widget, cairo_t *cr) {

	int noLine = 0;

	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(video_panel))) {

		if (!vlc_playing())  {
			gtk_widget_show(d1mask);
			return FALSE;
			}
		else
			gtk_widget_hide(d1mask);

		}

	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(no_graphs))) {
		gtk_widget_show(d1mask);
		return FALSE;
		}

	if (current_stack == visual)  {
		gtk_widget_show(d1mask);
		return FALSE;
		}
	else
		gtk_widget_hide(d1mask);

	draw_mode = DRAWS;

	DRAW_HEIGHT = 260.0;
	G_OFF = 4; // dashes if 2, continuous at 4
	G_OFF1 = 4;
	bar_space = 4.0;
	G_OFF_FREQ = G_OFF - 3.;

	LeftFlg = 0; // fix to place graphs in left panel

	graph_manager(cr, widget, noLine, SMALL_PANEL);

	return FALSE;
	}
