/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
#+
#+     Internet Radio Automation & Encoding Toolkit
#+
#+     Copyright (C) 2018, 2019, 2020, 2021 by Kevin C. O'Kane
#+
#+     Kevin C. O'Kane
#+     kc.okane@gmail.com
#+     https://www.cs.uni.edu/~okane
#+     https://threadsafebooks.com/
#+
#+ This program is free software; you can redistribute it and/or modify
#+ it under the terms of the GNU General Public License as published by
#+ the Free Software Foundation; either version 2 of the License, or
#+ (at your option) any later version.
#+
#+ This program is distributed in the hope that it will be useful,
#+ but WITHOUT ANY WARRANTY; without even the implied warranty of
#+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#+ GNU General Public License for more details.
#+
#+ You should have received a copy of the GNU General Public License
#+ along with this program; if not, write to the Free Software
#+ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#+
#++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/

//	Nov 4, 2022

#include "includes.h"
#include "common-externs.h"

#define SLASH '/'

//----------------------------------------------------
//      draw graphs in draw4 (visual) panel window.
//----------------------------------------------------

gboolean on_draw4_draw (GtkDrawingArea *widget, cairo_t *cr) {

	int noLine = 0;

	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(no_graphs)))  {
		gtk_widget_show(video_bg1);
		return FALSE;
		}

	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(no_graphs))) {
		gtk_widget_show(d1mask);
		return FALSE;
		}

	if (gtk_stack_get_visible_child(GTK_STACK(stack1)) != visual)
		return FALSE;

	gtk_widget_hide(video_bg1);

	DRAW_HEIGHT = 560.0;

	draw_mode = DRAWS1;

	G_OFF = 40;
	G_OFF1 = 40;
	bar_space = 6.0;

	G_OFF_FREQ = G_OFF - 3.;

//------------------------
//      Disable draw1
//------------------------

	graph_manager(cr, widget, noLine, LARGE_PANEL);

	return FALSE;
	}
